@@ -66,7 +66,7 @@ class ActsRecipe(GitCmakeRecipe):
             yield Append('LD_LIBRARY_PATH', os.path.join(path, 'lib'))
 
         # share/cmake/Acts
-        yield Append('CMAKE_PREFIX_PATH', os.path.join(path, 'share', 'cmake', 'Acts'))
+        yield Append('CMAKE_PREFIX_PATH', os.path.join(path, 'lib', 'cmake', 'Acts'))
 
     #
     # OS dependencies are a map of software packets installed by os maintainers
